==> mysql-8.0.32.tar.gz: mysql-8.0.32/storage/ndb/src/common/debugger/signaldata/FailRep.cpp <==
/*
   Copyright (c) 2003, 2022, Oracle and/or its affiliates.
    Use is subject to license terms.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#include <signaldata/FailRep.hpp>

bool printFAIL_REP(FILE *output,
                   const Uint32 *theData,
                   Uint32 len,
                   Uint16 /*receiverBlockNo*/)
{
  if (len < FailRep::OrigSignalLength)
  {
    assert(false);
    return false;
  }

  const FailRep *const sig = (const FailRep *)theData;

  fprintf(output, " FailedNode: %d, FailCause: %d\n", 
	  sig->failNodeId, sig->failCause);

  
  return true;
}

==> mysql-8.4_8.4.6.orig.tar.gz: mysql-8.4.6/storage/ndb/src/common/debugger/signaldata/FailRep.cpp <==
/*
   Copyright (c) 2003, 2025, Oracle and/or its affiliates.
    Use is subject to license terms.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#include <signaldata/FailRep.hpp>

bool printFAIL_REP(FILE *output, const Uint32 *theData, Uint32 len,
                   Uint16 /*receiverBlockNo*/) {
  if (len < FailRep::OrigSignalLength) {
    assert(false);
    return false;
  }

  const FailRep *const sig = (const FailRep *)theData;

  fprintf(output, " FailedNode: %d, FailCause: %d\n", sig->failNodeId,
          sig->failCause);

  return true;
}
